.. osirispy documentation master file, created by
   sphinx-quickstart on Thu Dec  8 22:28:03 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to osirispy's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :hidden:

   
   usage
   osirispy
   

Introduction
============

``osirispy`` is a python package for reading simulation output
for the particle-in-cell code OSIRIS. 

It utilizes the numpy interface to provide a simple way to read 
simulation output.



Installation
************

``osirispy`` is available on `PyPI <https://pypi.org/project/osirispy/>`_. 

You can install it by running the following command inside your terminal

.. code-block:: shell

    pip3 install osirispy


